import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

/// A widget that displays an IconButton based on the current platform.
/// [AdaptiveIconButton] is a CupertinoIconButton on iOS and macOS and a [IconButton] on Android, Windows and Web.
class AdaptiveIconButton extends StatelessWidget {

  /// A widget that displays an IconButton based on the current platform.
  const AdaptiveIconButton({
    Key? key,
    required this.icon,
    required this.onPressed,
  }) : super(key: key);

  /// The icon to display in the button.
  final Icon icon;

  /// The callback that is called when the button is pressed.
  final void Function()? onPressed;

  @override
  Widget build(BuildContext context) {
    final _isCupertino = Platform.isIOS || Platform.isMacOS;

    if (_isCupertino) {
      return CupertinoButton(
        onPressed: onPressed,
        padding: EdgeInsets.zero,
        child: icon,
      );
    }

    return IconButton(
      onPressed: onPressed,
      icon: icon,
    );
  }
}
