import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import '../app_bar/adaptive_app_bar.dart';

/// A widget that displays a Scaffold based on the OS
/// [AdaptiveScaffold] is a CupertinoScaffold on iOS and macOS and a Scaffold on Android, Windows and Web
class AdaptiveScaffold extends StatelessWidget {
  /// A widget that displays a Scaffold based on the OS
  const AdaptiveScaffold({
    Key? key,
    required this.body,
    required this.appBar,
  }) : super(key: key);

  /// The body of the scaffold
  final Widget body;

  /// The app bar
  final AdaptiveAppBar appBar;

  @override
  Widget build(BuildContext context) {
    final bool _isCupertino = Platform.isIOS || Platform.isMacOS;

    if (_isCupertino) {
      return CupertinoPageScaffold(
        child: NestedScrollView(
          headerSliverBuilder: (context, innerBoxIsScrolled) {
            return <Widget>[appBar];
          },
          body: body,
        ),
      );
    } else {
      return Scaffold(
        appBar: appBar as AppBar,
        body: body,
      );
    }
  }
}
