import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

/// A [TextField] that adapts to the current platform.
/// [AdaptiveTextField] is a [CupertinoTextField] on iOS and macOS and a [TextField] on Android, Windows and Web.
class AdaptiveTextField extends StatelessWidget {
  const AdaptiveTextField({
    Key? key,
    required this.controller,
    this.focusNode,
    this.maxLines = 1,
    this.keyboardType,
    this.textInputAction,
    this.cursorColor,
    this.materialInputDecoration,
    this.cupertinoDecoration,
    this.cupertinoPlaceholder,
    this.cupertinoTextStyle,
  }) : super(key: key);

  /// The [TextEditingController] for this [AdaptiveTextField].
  final TextEditingController controller;

  /// The [FocusNode] for this [AdaptiveTextField].
  final FocusNode? focusNode;

  /// The maximum number of lines.
  final int? maxLines;

  final TextInputType? keyboardType;
  final TextInputAction? textInputAction;
  final Color? cursorColor;
  final InputDecoration? materialInputDecoration;
  final BoxDecoration? cupertinoDecoration;
  final String? cupertinoPlaceholder;
  final TextStyle? cupertinoTextStyle;

  @override
  Widget build(BuildContext context) {
    final _isCupertino = Platform.isIOS || Platform.isMacOS;

    if (_isCupertino) {
      return CupertinoTextField(
        controller: controller,
        focusNode: focusNode,
        keyboardType: keyboardType,
        maxLines: maxLines,
        textInputAction: textInputAction,
        cursorColor: cursorColor,
        decoration: cupertinoDecoration,
        placeholder: cupertinoPlaceholder,
        style: cupertinoTextStyle,
      );
    }

    return TextField(
      controller: controller,
      focusNode: focusNode,
      keyboardType: keyboardType,
      maxLines: maxLines,
      textInputAction: textInputAction,
      cursorColor: cursorColor,
      decoration: materialInputDecoration,
    );
  }
}
